@@ -1,5 +1,5 @@
 from docopt import docopt
-import logic
+from usefulpy import logic
 
 def handle():
   command_router = logic.CommandRouter()
